@@ -2,13 +2,14 @@
 #ifndef NGX_HTTP_LUA_HOOK_H
 #define NGX_HTTP_LUA_HOOK_H
 
+
 #include "ngx_http_lua_common.h"
 
 #define NGX_LUA_EXCEPTION_TRY if (setjmp(ngx_http_lua_exception) == 0)
 #define NGX_LUA_EXCEPTION_CATCH else
 #define NGX_LUA_EXCEPTION_THROW(x) longjmp(ngx_http_lua_exception, (x))
 
-jmp_buf ngx_http_lua_exception;
+extern jmp_buf ngx_http_lua_exception;
 
 int ngx_http_lua_atpanic(lua_State *L);
 int ngx_http_lua_print(lua_State *L);
@@ -40,6 +41,8 @@ int ngx_http_lua_ngx_time(lua_State *L);
 int ngx_http_lua_ngx_localtime(lua_State *L);
 int ngx_http_lua_ngx_utctime(lua_State *L);
 int ngx_http_lua_ngx_cookie_time(lua_State *L);
+int ngx_http_lua_ngx_http_time(lua_State *L);
+int ngx_http_lua_ngx_parse_http_time(lua_State *L);
 int ngx_http_lua_ngx_redirect(lua_State *L);
 
 int ngx_http_lua_ngx_location_capture(lua_State *L);
@@ -48,15 +51,24 @@ int ngx_http_lua_ngx_location_capture_multi(lua_State *L);
 int ngx_http_lua_ngx_get(lua_State *L);
 int ngx_http_lua_ngx_set(lua_State *L);
 
-int ngx_http_lua_header_get(lua_State *L);
-int ngx_http_lua_header_set(lua_State *L);
+int ngx_http_lua_ngx_req_header_clear(lua_State *L);
+int ngx_http_lua_ngx_req_header_set(lua_State *L);
+
+int ngx_http_lua_ngx_header_get(lua_State *L);
+int ngx_http_lua_ngx_header_set(lua_State *L);
+
+int ngx_http_lua_ngx_req_get_headers(lua_State *L);
 
 int ngx_http_lua_ngx_exec(lua_State *L);
 
+#if defined(NDK) && NDK
 int ngx_http_lua_ndk_set_var_get(lua_State *L);
 int ngx_http_lua_ndk_set_var_set(lua_State *L);
-
 int ngx_http_lua_run_set_var_directive(lua_State *L);
+#endif
+
+ngx_int_t ngx_http_lua_post_subrequest(ngx_http_request_t *r,
+        void *data, ngx_int_t rc);
 
 
 #endif /* NGX_HTTP_LUA_HOOK_H */
